# A python implementation of the Poisson GLM using Radial Basis Functions. 

The codebase can also be used to to run the LNP model as well as the Poisson GLM using Raised Cosine Bumps. 
We have implemented the stimulus filter, post spike filter, as well as coupling filters for the different neurons.
We have also implemented the firing rate to compute the NLL of the neurons, as well as the probabilistic poisson spiking step
Finally, we implemented the fano factor to compare the predicted spike trains with the actual spike trains.